"use client"
import React, { useEffect, useState } from 'react'
import { RiMenu2Fill } from "react-icons/ri";
import { IoMdClose } from "react-icons/io";
import { ThemeSwitcher } from '../themeButton/ThemeButton';
import { useTheme } from 'next-themes';
import { styled } from '@mui/material/styles';
import FormGroup from '@mui/material/FormGroup';
import FormControlLabel from '@mui/material/FormControlLabel';
import Switch from '@mui/material/Switch';
import Stack from '@mui/material/Stack';
import Typography from '@mui/material/Typography';
import { getDictionary } from '../../../getDictionary';
import LanguageButton from '../languageButton/LanguageButton';

const IOSSwitch = styled((props) => (
    <Switch focusVisibleClassName=".Mui-focusVisible" disableRipple {...props} />
  ))(({ theme }) => ({
    width: 42,
    height: 26,
    padding: 0,
    '& .MuiSwitch-switchBase': {
      padding: 0,
      margin: 2,
      transitionDuration: '300ms',
      '&.Mui-checked': {
        transform: 'translateX(16px)',
        color: '#fff',
        '& + .MuiSwitch-track': {
          backgroundColor: '#65C466',
          opacity: 1,
          border: 0,
          ...theme.applyStyles('dark', {
            backgroundColor: '#2ECA45',
          }),
        },
        '&.Mui-disabled + .MuiSwitch-track': {
          opacity: 0.5,
        },
      },
      '&.Mui-focusVisible .MuiSwitch-thumb': {
        color: '#33cf4d',
        border: '6px solid #fff',
      },
      '&.Mui-disabled .MuiSwitch-thumb': {
        color: theme.palette.grey[100],
        ...theme.applyStyles('dark', {
          color: theme.palette.grey[600],
        }),
      },
      '&.Mui-disabled + .MuiSwitch-track': {
        opacity: 0.7,
        ...theme.applyStyles('dark', {
          opacity: 0.3,
        }),
      },
    },
    '& .MuiSwitch-thumb': {
      boxSizing: 'border-box',
      width: 22,
      height: 22,
    },
    '& .MuiSwitch-track': {
      borderRadius: 26 / 2,
      backgroundColor: '#E9E9EA',
      opacity: 1,
      transition: theme.transitions.create(['background-color'], {
        duration: 500,
      }),
      ...theme.applyStyles('dark', {
        backgroundColor: '#39393D',
      }),
    },
  }));

const Navbar = ({language,setLanguage}) => {
    const [data,setData] = useState({})
    

    useEffect(()=>{
        const getdata = async()=>{
            const lang = await getDictionary(language)
            await setData(lang);
        }
        getdata();
    })
    const { theme, setTheme } = useTheme()
    const [show, setShow] = useState(false)
  return (
    <div className={`${theme === 'light' ? "bg-white" : "bg-[#0a0a0a]"}  fixed top-0 z-30 left-0 right-0`}>
      <div className='h-[63px]  md:h-[83px]  flex justify-between w-[88%] mx-auto items-center md:pt-5'>
        <div className={`${theme === 'light' ? "text-[#0a0a0a]" : "text-white"}`}>
            techwelfare
        </div>

        <div className='hidden lg:flex'>
            <div className='text-[#7C7E82]  text-sm font-medium  py-2 px-6 hover:text-white rounded-full hover:bg-[#242424] inline-block duration-300 cursor-pointer'>Home</div>

            <div className='text-[#7C7E82]  text-sm font-medium  py-2 px-6 hover:text-white rounded-full hover:bg-[#242424] inline-block duration-300 cursor-pointer'>Solutions</div>

            <div className='text-[#7C7E82]  text-sm font-medium  py-2 px-6 hover:text-white rounded-full hover:bg-[#242424] inline-block duration-300 cursor-pointer'>Blog</div>

            <div className='text-[#7C7E82]  text-sm font-medium  py-2 px-6 hover:text-white rounded-full hover:bg-[#242424] inline-block duration-300 cursor-pointer'>About Us</div>

            <div className='text-[#7C7E82]  text-sm font-medium  py-2 px-6 hover:text-white rounded-full hover:bg-[#242424] inline-block duration-300 cursor-pointer'>Contact Us</div>
        </div>


        <div className=' flex gap-5 items-center'>
        <div> <ThemeSwitcher/>  </div>
        <div> 
            <FormControlLabel
        onClick={()=>setLanguage(language === 'en' ? 'ar':'en')}
        control={<IOSSwitch sx={{ m: 1 }} defaultChecked />}
        label={language}
      /> </div>
            <div className={` text-sm font-medium p-2 lg:py-2 px-4 lg:px-6  rounded-full
                ${theme === 'light' ? "text-[#0a0a0a] border-[#0a0a0a] border" : "text-white border"} inline-block cursor-pointer   relative overflow-hidden group  `}>
                <div
                    className={`absolute transition-transform z-0 flex items-center justify-center  duration-1000 group-hover:-translate-y-8 delay-100 transform ${theme === 'light' ? "text-black" : "text-white"}`}>
                    Get Started
                    </div>
        
                    <div
                    className={`transition-transform  z-10  group-hover:flex  duration-1000 translate-y-8 group-hover:-translate-y-0 group-hover:opacity-100  transform ${theme === 'light' ? "text-black" : "text-white"}`}>
                    Get Started
                    </div>
        </div>

            {
                !show && 
                <div onClick={()=>setShow(true)} className='flex lg:hidden cursor-pointer'>
                    <RiMenu2Fill size={25} color='#7C7E82'/>
                </div>
            }


            {
                show && 
                <div onClick={()=>setShow(false)} className='flex lg:hidden cursor-pointer'>
                    <IoMdClose size={27} color='#7C7E82'/>
                </div>
            }
        </div>

      </div>

    {
        show && 
      <div className={` z-20 lg:hidden ${theme === 'light' ? "bg-white" : "bg-[#0a0a0a]"}  fixed top-[60px] left-0 right-0 bottom-0 flex flex-col justify-between pt-4`}>

            <div className=' flex flex-col w-[91%] mx-auto'>
                <div className='text-[#7C7E82]  text-base font-medium  py-2 px-6 hover:text-white rounded-full hover:bg-[#242424] inline-block duration-300 cursor-pointer'>Home</div>

                <div className='text-[#7C7E82]  text-base font-medium  py-2 px-6 hover:text-white rounded-full hover:bg-[#242424] inline-block duration-300 cursor-pointer'>Solutions</div>

                <div className='text-[#7C7E82]  text-base font-medium  py-2 px-6 hover:text-white rounded-full hover:bg-[#242424] inline-block duration-300 cursor-pointer'>Blog</div>

                <div className='text-[#7C7E82]  text-base font-medium  py-2 px-6 hover:text-white rounded-full hover:bg-[#242424] inline-block duration-300 cursor-pointer'>About Us</div>
                
                <div className='text-[#7C7E82]  text-base font-medium  py-2 px-6 hover:text-white rounded-full hover:bg-[#242424] inline-block duration-300 cursor-pointer'>Contact Us</div>
            </div>

            <div className={`w-[90%] mx-auto flex justify-center mb-5 text-sm font-medium p-2 lg:py-2 px-4 lg:px-6  rounded-full
                ${theme === 'light' ? "text-[#0a0a0a] border-[#0a0a0a] border" : "text-white border"} inline-block cursor-pointer   relative overflow-hidden group  `}>
                <div
                    className={`absolute transition-transform z-0 flex items-center justify-center  duration-1000 group-hover:-translate-y-8 delay-100 transform ${theme === 'light' ? "text-black" : "text-white"}`}>
                    Get Started
                    </div>
        
                    <div
                    className={`transition-transform  z-10  group-hover:flex  duration-1000 translate-y-8 group-hover:-translate-y-0 group-hover:opacity-100  transform ${theme === 'light' ? "text-black" : "text-white"}`}>
                    Get Started
                    </div>
            </div>
        </div>
    }

    </div>
  )
}

export default Navbar
